
;
;    Written by: Art Whitton - CAD/CAM SET4B
;    Date: February 4, 1997
;
;    Description: THIS PROGRAM WILL DISPLAY A DIALOG BOX THAT WILL PROMPT 
;                 FOR THE VALUES NEEDED TO COMPLETE A A4 TITLE BLOCK AND INSERT
;                 IT INTO THE DRAWING.
;
;    Required Functions: setup  ;  tb     
;    Required Programs : a4_title.dwg // contains the attributed title block
;         
;    Variable Listing:
;
; Name       	Scope     Type      	Description
; date		global	string	stores the value from the date tile "dayte"
; dayte		global	string	tile value for the date
; dia_id	global	real	ID value for the dialog box
; drwnby	global	string	stores the value from the tile "drwn_by"
; dwgname	global	string 	stores the value from the tile "dwg_name"
; dwgnum	global	string 	stores the value from the tile "dwg_num"
; error_ch	local	real	local to "tb" / stores the error check for dwgnum
; rot		global	real	stores the rotation angle for insertion from the tile "rot"
; scal		global	string	stores the value taken from the "scale_list" based on "scale_ch"
; scale_ch	global	string	stores the value from the popup_list "skale"
; scale_list	global	list	list of values that fill the popup_list "skale"
; size		global	string	stores the value taken from the "size_list" based on "size_ch"
; size_ch	global	string	stores the value from the popup_list "size"
; size_list	global	list	list of values that fill the popup_list "size"
; title		global	string	the name of the .DWG file that has the title block
; x_scale	global	real	converted value of tile "x_scale" used for inserting the block
; y_scale	global	real	converted value of tile "y_scale" used for inserting the block

;***********************************************************************

;
;***************  FUNCTION TO SETUP THE TILE VALUES  *******************
;
(defun setup ()
   (set_tile "dwg_name" "No name yet")
   (set_tile "drwn_by" "AJW")      ; SET DEFAULT VALUES IN EDIT_BOXES
   (set_tile "dwg_num" "xxxx0000-0")
   (setq dayte (getvar "CDATE"))
   (set_tile "dayte" ( rtos dayte 2 0 ))
   (set_tile "x_scale" "1")
   (set_tile "y_scale" "1")
   (set_tile "rot" "0")
   (setq scale_list ( list "100:1" "50:1" "25:1" "10:1" "4:1" "2:1" "1:1" "1:2" "1:4" "1:5" "1:10" ))
   (start_list "skale" )
   (foreach value scale_list (add_list value))  ; /* LOOP THROUGH LIST AND GET VALUES */
   (end_list)
   (setq size_list ( list "A0" "A1" "A2" "A3" "A4" "B" "C" "D" "E"))
   (start_list "size" )
   (foreach value size_list (add_list value))
   (end_list)
)
;
;***************  SHORT HELP ALERT BOX FUNCTION  ***********************
;

(defun help_me ()
  (alert "The first 3 boxes will fill in the\nattributes,and the last one will fill in \nthe values for the insert command.")
)

;
;***************  FUNCTION TO RETRIEVE THE TILE VALUES  ***************
;

(defun tb ()
   (setq error_ch 0)
   (setq title "a4_title")        ; NAME OF THE .DWG FILE WITH TITLE BLOCK
   (setq dwgname (strcase (get_tile "dwg_name")))
   (if (= dwgname "")
      (progn
      (mode_tile "dwg_name" 2)
      (set_tile "error" "** DWG NAME FIELD CAN NOT BE EMPTY **")
      (setq error_ch 1)
      )
   )
   (setq date (strcase (get_tile "dayte")))  ; 'STRCASE' CONVERTS TO UPPER 
   (if (= date "")
      (progn
      (mode_tile "dayte" 2)
      (set_tile "error" "** DATE FIELD CAN NOT BE EMPTY **")
      (setq error_ch 1)
      )
   )
   (setq drwnby (strcase (get_tile "drwn_by")))
   (if (= drwnby "")
      (progn
      (mode_tile "drwn_by" 2)
      (set_tile "error" "** DRAWN BY FIELD CAN NOT BE EMPTY **")
      (setq error_ch 1)
      )
   )
   (setq scale_ch (get_tile "skale"))
      (setq scal (nth (atoi scale_ch) scale_list))
   (setq size_ch (get_tile  "size"))
      (setq size (nth (atoi size_ch) size_list))
   (setq dwgnum (strcase (get_tile "dwg_num")))
   (if (/= (wcmatch dwgnum "@@@@####-#") T)
      (progn
      (mode_tile "dwg_num" 2)
      (set_tile "error" "** INVALID DRAWING NUMBER ** (Format is: xxxx1234-5)")
      (setq error_ch 1)
      )
   )   
   (setq x_scale (atof (get_tile "x_scale")))
   (setq y_scale (atof (get_tile "y_scale")))
   (setq rot (atof (get_tile "rot")))
   (if (= error_ch 0)
      (done_dialog 1)
   )
)
****************  FUNCTION TO CHECK FOR CANCEL  ************************

(defun go_away()
   (setq error_ch 1)
)

;***********************************************************************
;***************  MAIN PROGRAM  ****************************************
;***********************************************************************

(defun c:tba (   )
    (setq dia_id (load_dialog "tba.dcl"))
    (if (new_dialog "titl_blok" dia_id)
       (progn
       (setup)   
       (action_tile "accept" "(tb)")
       (action_tile "help" "(help_me)")
       (action_tile "cancel" "(go_away)")
       (start_dialog)
       (unload_dialog dia_id)
       )
      (alert "Dialog box not available.  Check search path")
    )
 (if (= error_ch 0)  ; /* WILL NOT EXECUTE IF ERROR_CH != 0 */
    (command "insert" title pause x_scale y_scale rot date dwgname scal drwnby dwgnum size)
 )
 (princ)
)
 (princ "Loaded. . . type <tba> to run.")
 (princ)

